#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh
. ./netlib.sh
. ./namelib.sh

echo "Content-Type: application/json"
echo ""

HOSTNAME=""

if [[ -n "$1" ]]; then
    echo "$1" | grep "[^0-9a-zA-Z-]" > /dev/null 2>&1
    if [ "$?" -eq "0" ]; then
        json_error $ERR_HOSTNAME "Invalid hostname specified!"
        exit 1
    fi
    HOSTNAME="$1"
else
    json_error $ERR_HOSTNAME "Invalid hostname specified!"
    exit 1
fi

set_upnp_friendly_name "$HOSTNAME"
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    if [[ $RETCODE -eq $ERR_UPNPNAME ]]; then
        json_error $ERR_UPNPAME "Could not set UPnP friendly name!"
    fi
    exit $RETCODE
fi

REDIR=$(set_hostname "$HOSTNAME")
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    if [[ $RETCODE -eq $ERR_FWRITE ]]; then
        json_error $ERR_FWRITE "Could not write to hostname file!"
    elif [[ $RETCODE -eq $ERR_HOSTNAME ]]; then
        json_error $ERR_HOSTNAME "Could not set hostname!"
    elif [[ $RETCODE -eq $ERR_NETUP ]] || [[ $RETCODE -eq $ERR_NETDOWN ]]; then
        json_error $RETCODE "Error restarting network!"
    elif [[ $RETCODE -eq $ERR_REDIRECT ]] || \
         [[ $RETCODE -eq $ERR_REDIRECT_NAME ]]; then
        json_redirect $RETCODE "`echo $REDIR | cut -d ':' -f 1`" \
                        "`echo $REDIR | cut -d ':' -f 2`"
    elif [[ $RETCODE -eq $ERR_QUIT ]]; then
        exit 0
    fi

    exit $RETCODE
fi

json_ok
