XMLLINT="/usr/bin/xmllint"
RUNIT_DOWN=0
RUNIT_UP=1
RUNIT_STATUS=2

log() {
    LOGFILE="/var/log/dss11-websetup/dss11-websetup.log"
    if [[ -n "$2" ]]; then
        LOGFILE="$2"
    fi
    echo "`date +"%Y-%m-%d %H:%M:%S"` $1" >> "$LOGFILE"
}

check_xml_file() {
    $XMLLINT --noout "$1" >/dev/null 2>&1
    if [[ $? -ne $ERR_OK ]]; then
        return $ERR_XML
    fi

    return $ERR_OK
}

check_host_name() {
    FILE="/etc/hostname"
    if [[ -n "$1" ]]; then
        FILE="$1"
    fi

    if [[ ! -f $FILE ]]; then
        return $ERR_FILENOTFOUND
    fi

    LINES=$(wc -l $FILE | awk '{ print $1}')
    if [[ $LINES -gt 1 ]]; then
        return $ERR_INVALID
    fi
    
    LEN=$(wc -c $FILE | awk '{ print $1}')
    if [[ $LEN -eq 0 ]]; then
        return $ERR_INVALID
    fi

    egrep '^[0-9A-Za-z-]+$' $FILE > /dev/null 2>&1
    if [[ $? -ne 0 ]]; then
        return $ERR_INVALID
    fi

    return $ERR_OK
}

check_ssh_config() {
    FILE="/etc/default/dropbear"
    if [[ -n "$1" ]]; then
        FILE="$1"
    fi

    if [[ ! -f $FILE ]]; then
        return $ERR_FILENOTFOUND
    fi

    OPTION=$(egrep NO_START $FILE | cut -d '=' -f 2)
    echo $OPTION | grep '^[0-1]$' > /dev/null 2>&1
    if [[ $? -ne 0 ]]; then
        return $ERR_INVALID
    fi

    return $ERR_OK
}

check_ntp_config() {
    FILE="/etc/default/ntpclient"
    if [[ -n "$1" ]]; then
        FILE="$1"
    fi

    if [[ ! -f $FILE ]]; then
        return $ERR_FILENOTFOUND
    fi

    ENABLED=$(egrep ENABLED /etc/default/ntpclient  | \
             cut -d '=' -f 2 | egrep '(yes|no)')
    if [[ -z "$ENABLED" ]]; then
        return $ERR_INVALID
    fi

    if [[ "$ENABLED" == "yes" ]]; then
        SERVER=$(egrep NTPSERVER /etc/default/ntpclient  | cut -d '=' -f 2)
        if [[ -z "$SERVER" ]]; then
            return $ERR_INVALID
        fi
    fi

    return $ERR_OK
}


control_dss() {
    if [[ -f "/etc/runit/dss/supervise/stat" ]]; then
        STATUS=`cat /etc/runit/dss/supervise/stat`
        if [[ $1 -eq $RUNIT_STATUS ]]; then
            if [[ "$STATUS" == "run" ]]; then
                return $RUNIT_UP
            else
                return $RUNIT_DOWN
            fi
        fi
     
        if [[ $1 -eq $RUNIT_DOWN ]] && [[ "$STATUS" == "run" ]]; then
            sv force-stop /etc/runit/dss > /dev/null 2>&1
            sleep 3
            if [[ -n "`pidof dss`" ]]; then
                killall -9 dss > /dev/null 2>&1
                sleep 1
            fi
            return $ERR_OK
        elif [[ $1 -eq $RUNIT_UP ]] && [[ "$STATUS" == "down" ]]; then
            sv up /etc/runit/dss > /dev/null 2>&1
        fi
    else
        if [[ $1 -eq $RUNIT_STATUS ]]; then
            if [[ -n "`pidof dss`" ]]; then
                return $RUNIT_UP
            else
                return $RUNIT_DOWN
            fi
        fi
    fi
}
