Ext.namespace('dSS11', 'dSS11.sys');

dSS11.sys.BackupRestoreForm = Ext.extend(Ext.form.FormPanel,
{
    initComponent: function()
    {
        this.download = document.createElement("iframe");
        //  elemIF.src = '/cgi-bin/dobackup.sh';
        this.download.style.display = "none";
        document.body.appendChild(this.download);

        Ext.apply(this, {
            fileUpload: true,
            layout: 'fit',
            bodyBorder: false,
            items:
            [
                {
                    xtype: 'fieldset',
                    ref: 'mainSet',
                    title: _("Backup and restore settings"),
                    layout: 'absolute',
                    height: 228,
                    scope: this,
                    items:
                    [
                        {
                            xtype: 'label',
                            cls: 'x-green-text',
                            html: _("In order to backup the system settings, " +
                                    "given names and all App configurations, " +
                                    "the data can be downloaded using the " +
                                    "backup button.") + '<br/>' +
                                  _("Note: dSM and device data such as " +
                                    "room-setup or activity settings will " +
                                    "not be stored."),
                            x: 0,
                            y: 3
                        },
                        {
                            text: _("Backup"),
                            xtype: 'button',
                            handler: this.generateBackup.createDelegate(this),
                            minWidth: 110,
                            x: 255,
                            y: 85
                        },
                        {
                            xtype: 'label',
                            cls: 'x-green-text',
                            text: _("Restoring the data will overwrite all " +
                                    "changes done on the system."),
                            x: 0,
                            y: 115
                        },
                        {
                            xtype: 'fileuploadfield',
                            emptyText: _("Select file to restore"),
                            fieldLabel: _("File to restore"),
                            buttonOffset: 15,
                            name: 'upload',
                            width: 365,
                            x: 0,
                            y: 155,
                            buttonCfg: {
                                text: _("Browse") + "...",
                                minWidth: 110
                            },
                            validator: this.validateFile.createDelegate(this)
                        },
                        {
                            text: _("Restore"),
                            ref: 'restoreButton',
                            scope: this,
                            xtype: 'button',
                            disabled: true,
                            handler: this.restoreBackup.createDelegate(this),
                            minWidth: 110,
                            x: 255,
                            y: 185
                        }
                    ]
                }
            ]
        });

        dSS11.sys.BackupRestoreForm.superclass.initComponent.apply(this, arguments);
    },
    generateBackup:  function() {
        var maskEl = this.findParentByType('viewport').el;

        maskEl.mask(_("Please wait, generating backup") + '...',
                    'x-mask-loading');
        Ext.Ajax.request({
                url: '/cgi-bin/preparebackup.sh',
                method: 'GET',
                timeout: 300000,
                scope: this,
                success: function(response) {
                    maskEl.unmask();
                    var jsonData = Ext.util.JSON.decode(response.responseText);
                    if ((jsonData.success !== true) ||
                        (jsonData.code !== dSS11.config.codes.ERR_OK)) {
                        Ext.Msg.alert(_("Error"), _(jsonData.message));
                    } else {
                        this.download.src =
                            '/cgi-bin/downloadbackupwrapper.sh' + '?id=' +
                            encodeURIComponent(jsonData.data.backup);
                    }
                },
                failure: function(response) {
                    maskEl.unmask();
                    try {
                        var jsonData = Ext.util.JSON.decode(
                                                response.responseText);
                        if (jsonData.code !== dSS11.config.codes.ERR_OK) {
                            Ext.Msg.alert(_("Error"), _(jsonData.message));
                        }
                    } catch (error) {
                        Ext.Msg.alert(_("Error"), error);
                    }

                }
            }
        );
    },
    restoreBackup: function() {
        if (this.getForm().isValid()) {
            this.getForm().submit({
                url: '/cgi-bin/restorebackup.hs',
                waitTitle: _("Please wait"),
                waitMsg: _("Restoring settings from backup") + "...",
                scope: this,
                success: function(form, action) {
                    try {
                        var jsonData = Ext.util.JSON.decode(
                                                action.response.responseText);
                        if (jsonData.code === dSS11.config.codes.ERR_REDIRECT) {
                            if (jsonData.ip.length > 0) {
                                this.findParentByType('viewport').el.mask(
                                _(jsonData.message), 'x-mask-loading');
                                window.location = 'http://' + jsonData.ip;
                            }
                        } else if (jsonData.code ===
                                    dSS11.config.codes.ERR_REDIRECT_NAME) {
                            this.findParentByType('viewport').el.mask(
                                _("Backup applied, reloading page") + "...");
                            window.location = 'http://' + jsonData.ip;
                        } else if (jsonData.code ===
                                                dSS11.config.codes.ERR_OK) {
                            this.findParentByType('viewport').el.mask(
                                _("Backup applied, reloading page") + "...");
                            window.location.reload();
                        } else {
                            Ext.Msg.alert(_("Error"), _(jsonData.message));
                        }
                    } catch (error) {
                        Ext.Msg.alert(_("Error"), error);
                    }
                },
                failure: function(form, action) {
                    try {
                        var jsonData = Ext.util.JSON.decode(
                                                action.response.responseText);
                        if (jsonData.code !== dSS11.config.codes.ERR_OK) {
                            Ext.Msg.alert(_("Error"), _(jsonData.message));
                        }
                    } catch (error) {
                        Ext.Msg.alert(_("Error"), error);
                    }
                }
            });
        }
    },
    validateFile: function(text) {
        var ex = /dss_backup_[0-9]{4}\-[0-9]{2}\-[0-9]{2}_[0-9]{6}\.tar\.gz/;
        if (ex.exec(text) === null) {
            this.mainSet.restoreButton.disable();
            return _("Invalid backup file");
        }
        this.mainSet.restoreButton.enable();
        return true;
    }
});

Ext.reg('dss11backuprestore', dSS11.sys.BackupRestoreForm);
